@@ -71,7 +71,7 @@ def student_token_file_runner(host_tmp_dir, student_token_file, instructor_grade
     return pycom, token_location
 
 
-def docker_run_token_file(Dockerfile_location, host_tmp_dir, student_token_file, instructor_grade_script=None):
+def docker_run_token_file(Dockerfile_location, host_tmp_dir, student_token_file, tag=None, instructor_grade_script=None):
     """
     This thingy works:
 
@@ -110,7 +110,10 @@ def docker_run_token_file(Dockerfile_location, host_tmp_dir, student_token_file,
     """
     docker run -v c:/Users/tuhe/Documents/2021/python-docker/tmp:/home python-docker python3 -m cs202courseware.ug2report1_grade
     """
-    dockname = os.path.basename( os.path.dirname(Dockerfile_location) )
+    if tag is None:
+        dockname = os.path.basename( os.path.dirname(Dockerfile_location) )
+    else:
+        dockname = tag
 
     tmp_grade_file =  sources['name'] + "/" + sources['report_relative_location']
 
